# novice

1.geo_map: reverse Geocoder takes a latitude / longitude coordinate and returns the nearest town/city.
2.bert_extracter: Extract text features from bert.
3.rule_engine: A simple extensible rules engine implemented in Python.
4.score_card: A complete score card process.[bins,woe,model_pre,score,auc,ks,lift,psi,csi]